# OpenDR Speech Recognition - EdgeSpeechNets

This folder contains the OpenDR learner for EdgeSpeechNets.

## Sources

The algorithm files were written from scratch based on the paper [EdgeSpeechNets: Highly Efficient Deep Neural Networks for Speech Recognition on the Edge](https://arxiv.org/abs/1810.08559).